

SIARecord
======================

.. currentmodule:: pyvo.dal.sia

.. autoclass:: SIARecord
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SIARecord.acref
      ~SIARecord.dateobs
      ~SIARecord.dec
      ~SIARecord.format
      ~SIARecord.instr
      ~SIARecord.naxes
      ~SIARecord.naxis
      ~SIARecord.ra
      ~SIARecord.title

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~SIARecord.getdataurl
      ~SIARecord.suggest_dataset_basename
      ~SIARecord.suggest_extension

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: acref
   .. autoattribute:: dateobs
   .. autoattribute:: dec
   .. autoattribute:: format
   .. autoattribute:: instr
   .. autoattribute:: naxes
   .. autoattribute:: naxis
   .. autoattribute:: ra
   .. autoattribute:: title

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: getdataurl
   .. automethod:: suggest_dataset_basename
   .. automethod:: suggest_extension

   
   